# Eufy unofficial API
This library is able to connect on eufy security api on mysecurity.eufylife.com and expose methods and model to interact with it in Python.

Install with:
> pip install uefy-security-api-rihan==0.0.1

TODO List:

- [ ] Write decent readme. Sorry.
- [ ] Way to set params with this api. Currently is read only access